meteolib
========

A python module conatins standard equations, constants and conversions adopted or recommended by the [World meteorological Organization (WMO)](http://www.wmo.int) for general use in meteorology.

Requirements:
-------------

    pip install numpy pandas

Installation:
-------------
As root or Administrator:

    pip install meteolib

or as normal user: 

    pip install --user meteolib

or manually install the sources 
available from [GitHub](https://github.com/cdruee/meteolib)


Documentation: <http://druee.gitlab-pages.uni-trier.de/meteolib/>
--------------


